@@ -14,18 +14,9 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-//#include <vector>
-//#include <string>
-//#include "definitions.h"
 
 bool verbose = false;
+bool very_verbose = false;
 bool global_enable = true;
 extern "C" void ac_check_lineak(void) {
 }
-//vector<string> specials;
-//specials.push_back(EAK_EJECT);
-//specials.push_back(EAK_VOLUP);
-//specials.push_back(EAK_VOLDOWN);
-//specials.push_back(EAK_MUTE);
-//specials.push_back(EAK_SLEEP);
-//specials.push_back(EAK_SCREEN_LOCK);
