@@ -87,13 +87,18 @@ bool LCommand::operator==(const LCommand& rhs) {
    if (macro_type != rhs.macro_type) return false;
    if (command != rhs.command) return false;
 
-   vector<string>::const_iterator it = args.begin();
-   vector<string>::const_iterator rit = rhs.args.begin();
-   for (; it != args.end() && rit != rhs.args.end(); )
-      if (*it != *rit) return false;	
-      it++;
-      rit++;
-  }
+   if (args.size() == rhs.args.size() ) {
+      vector<string>::const_iterator it = args.begin();
+      vector<string>::const_iterator rit = rhs.args.begin();
+      for (; it != args.end() && rit != rhs.args.end(); ) {
+         if (*it != *rit) return false;	
+         it++;
+         rit++;
+      }
+   }
+   else
+      return false;
+ }
  return true;
 }
 
