@@ -380,6 +380,9 @@ bool lineak_core_functions::is_running(string process) {
       return -1;
    }
          
+   if (verbose)
+	   cout << "Looking for " << process << endl;
+
    while ((d = readdir(dir)) != NULL)
    {
       // See if this is a process
@@ -404,7 +407,11 @@ bool lineak_core_functions::is_running(string process) {
          in >> str;
          in >> str;
          in.close();
-         if (str.find("(" + process) != string::npos && (mypid != pid)) {
+//	 if (verbose) 
+//		 cout << "Stat: " << str << endl;
+
+	 // Only look for the first 15 characters as linux cuts off the stat entries after 15 characters. 
+         if (str.find("(" + process.substr(0,15)) != string::npos && (mypid != pid)) {
     		if (verbose) cout << "*** " << process << " is running (pid " << pid << ")" << endl;
                 if (verbose) cout << "*** mypid: " << mypid << endl;
                 if (verbose) cout << str << endl;
@@ -480,6 +487,12 @@ string lineak_core_functions::getEventTypeString(EventType_t event_type) {
 	}
 	return "UNKNOWN";
 }
+EventType_t lineak_core_functions::getEventType(string event_type) {
+	if (event_type == "PRESS")
+		return PRESS;
+	if (event_type == "RELEASE")
+		return RELEASE;
+}
 string lineak_core_functions::getTypeString(KeyType_t type) {
 	switch (type) {
 		case SYM:
@@ -496,6 +509,14 @@ string lineak_core_functions::getTypeString(KeyType_t type) {
 	}
 	return "UNKNOWN";
 }
+KeyType_t lineak_core_functions::getType(string type) {
+        if (type == "SYM")
+		return SYM;
+        if (type == "CODE")
+		return CODE;
+        if (type == "BUTTON")
+		return BUTTON;
+}
 unsigned int lineak_core_functions::getModifierNumericValue(const string modstr) {
 	string modifiers = modstr;
 	unsigned int modifier = 0;
@@ -518,11 +539,11 @@ unsigned int lineak_core_functions::getModifierNumericValue(const string modstr)
 	for (vector<string>::iterator it = mods.begin(); it != mods.end(); it++) {
 	    
 	      /* build the modifier */
-	      if (*it == "control")
+	      if (*it == "control" || *it == "Control_L" || *it == "Control_R" )
 	         modifier |= ControlMask;
-	      else if (*it == "shift")
+	      else if (*it == "shift" || *it == "Shift_L" || *it == "Shift_R" )
 	         modifier |= ShiftMask;
-	      else if (*it == "mod1" || *it == "alt") {
+	      else if (*it == "mod1" || *it == "alt" || *it == "Alt_L" || *it == "Alt_R" ) {
 	         modifier |= Mod1Mask;
 		 //cout << "adding Mod1Mask modifier to " << keyname << endl;
 	      }
@@ -566,29 +587,15 @@ unsigned int lineak_core_functions::getModifierNumericValue(const string modstr)
 }
 
 void lineak_core_functions::enable_IBMRA7993(void) {
-   lineak_core_functions::send_commands("ea 71");
+   lineak_core_functions::send_commands("send_to_keyboard", "ea 71");
 }
 
-void lineak_core_functions::send_commands(string args) {
-/*   int x;
-
-   string st;
-   istringstream SString( args );
-
-   if (ioperm(0x60, 3, 1) == -1) {
-      perror("ioperm failed.");
-   } 
-
-   while ( SString >> st ) {
-      if (verbose) cout << "Running command: " << st << endl;
-
-      x = strtol(st.c_str(),0,16);
-      usleep(300);
-      outb(x, 0x60);
-   }
-   */
-  string comm = SBINDIR;
-  comm += "/send_to_keyboard ";
+void lineak_core_functions::send_commands(string command, string args) {
+  string comm;
+  //comm += SBINDIR;
+  //comm += "/";
+  comm += command;
+  comm += " ";
   comm += args;
   comm += " &";
 
@@ -597,6 +604,7 @@ void lineak_core_functions::send_commands(string args) {
         /* child process that tries to run the command, and then exits */
         /* all specials done, let's go for it... ;) */
         if (verbose) cout << "... running " << comm << endl;
+        //system("which setkeycodes");
         system(comm.c_str());
         exit(true);
   }
