@@ -45,6 +45,8 @@ class LKey : public LObject {
          keycount = 0;
       }
       virtual void print(ostream&out);
+      virtual void serialize(ostream &out);
+      virtual void unserialize(istream &in);
       void setKeySym(KeySym ikeysym);
       void setKeyCode(KeyCode code);
 
@@ -66,5 +68,6 @@ class LKey : public LObject {
 };
 
 ostream & operator<<(ostream &out, LKey &rhs);
+istream & operator>>(istream &in, LKey &rhs);
 
 #endif
