@@ -116,6 +116,40 @@ string LObject::getEventTypeString() {
 string LObject::getTypeString() {
 	return lineak_core_functions::getTypeString(type);
 }
+void LObject::serialize(ostream &out) {
+   int com=0;
+   if (name != snull) {
+      out << "object=" << name;
+      out << ":event_type=" << lineak_core_functions::getEventTypeString(event_type);
+      out << ":type=" << lineak_core_functions::getTypeString(type);
+      if (!isToggle()) {
+          out << ":toggle=false";
+          for (map<unsigned int,LCommand>::iterator i = commands.begin(); i!= commands.end(); i++, com++) {
+	     out << ":command_entry=" << com;
+             out << ",modifier=" << lineak_core_functions::getModifierString((i->first));
+             out << ",command=" << commands[(i->first)];
+             out << ",display_name=" << commandDisplayNames[(i->first)];
+          }
+       }
+       else {
+          out << ":toggle=true" << endl;
+          string s;
+          for (queue<string>::size_type i = 0; i<toggle_names.size(); i++, com++) {
+             s = toggle_names.front();
+	     out << ":command_entry=" << com;
+             out << ",toggle_name=" << s;
+             out << ",command=" << tog_commands[s];
+             out << ",display_name=" << tog_commandDisplayNames[s];
+             toggle_names.pop();
+             toggle_names.push(s);
+          }
+      }
+  }
+  else {
+    error("Attempting to output an empty key!");
+  }
+}
+
 void LObject::print(ostream&out) {
    if (name != snull) {
       out << "Object: " << name << endl;
@@ -219,6 +253,7 @@ void LObject::clear() {
 }
 
 ostream & operator<<(ostream &out, LObject &rhs) {
+        //rhs.serialize(out);
         rhs.print(out);
         return out;
 }
