@@ -68,8 +68,10 @@ class LObject {
       virtual string getEventTypeString();
       virtual string getTypeString();
       virtual void print(ostream &out);
+      virtual void serialize(ostream &out);
+      virtual void unserialize(/*istream &in*/) {/** This doesn't do anything yet*/};
       
-      // TOGGLE SHIT. This is where this gets nasty.
+      // TOGGLE SHIT. This is where this gets nasty, probably as a result of poor OO design on my part.
       /** Return whether or not this is a toggleable key. The distinction is
           necessary for on screen display where you have a config file entry of the
 	  form:
@@ -115,8 +117,6 @@ class LObject {
       map<string,string> tog_commandDisplayNames;
       queue<string> toggle_names;
       
-   //private:
-   //   void internal_init();
 };
 
 ostream & operator<<(ostream &out, LObject &rhs);
