@@ -38,6 +38,7 @@ extern "C" {
 
 using namespace lineak_core_functions;
 extern bool verbose;
+extern bool very_verbose;
 extern bool global_enable;
 
 PluginManager::PluginManager() {
@@ -109,7 +110,10 @@ bool PluginManager::loadPlugin(const string& plugin) {
                 msg("plugin type:" + type);
 		msg("plugin version: " + version); 
 		msg("plugin_ident: " + description);
-		if (VERSION != version) {
+		int Vsize = string(VERSION).size();
+		//cout << "Comparing: " << VERSION << " to the first " << Vsize << " characters of: " << version.substr(0,Vsize) << endl;
+                if (VERSION != version.substr(0,Vsize)) { 
+		//if (VERSION != version) {
 			msg("Warning: Version mismatch. Unloading plugin.");
                         dlerror();
                         dlclose(handle);
@@ -265,7 +269,7 @@ bool PluginManager::loadPlugin(const string& plugin) {
 	plinfo.initialized = false;
 	plinfo.macros.clear();
 	plinfo.directives.clear();
-        if (verbose) cout << "Entering plugin: " << name << endl;
+        vmsg("Entering plugin: " + name);
 //	if (verbose) cout << "plinfo ---------" << endl;
 //	if (verbose) cout << plinfo << endl;
 	plugin_map[name] = plinfo;
@@ -302,21 +306,21 @@ vector<string> PluginManager::loadPlugins(vector<string> myplugins) {
 }
 /** Unload a plugin */
 void PluginManager::unloadPlugin(const string& plugin) {
-	msg("unloadPlugin: enter for plugin " + plugin);
+	vmsg("unloadPlugin: enter for plugin " + plugin);
 	void* handle = NULL;
 	cleanup_t cleanup = NULL;
-	msg("PluginManager: cleaning up plugin " + plugin);
+	vmsg("PluginManager: cleaning up plugin " + plugin);
 	handle = plugin_map[plugin].handle;
 	cleanup = plugin_map[plugin].cleanup;
 	if (cleanup != NULL)
                  cleanup();
-        msg("PluginManager: closing plugin " + plugin);
+        vmsg("PluginManager: closing plugin " + plugin);
         if (handle != NULL) {
                 dlclose(handle);
         }
-	msg("PluginManager: removing plugin " + plugin);
+	msg("PluginManager: unloading plugin " + plugin);
 	plugin_map.erase(plugin);
-        msg("UnloadPlugin: exit");
+        vmsg("UnloadPlugin: exit");
 }
 /** Unloads all loaded plugins. */
 void PluginManager::unloadAllPlugins(){
@@ -324,10 +328,10 @@ void PluginManager::unloadAllPlugins(){
    	map<string,plugin_info>::iterator it = plugin_map.begin();
         msg("PluginManager is unloading plugins");
 	for (;it != plugin_map.end(); it++) {
-                if (verbose) cout << "Calling unload for plugin: " << it->first << endl;
-		//unloadPlugin(it->first);
+                if (very_verbose) cout << "Calling unload for plugin: " << it->first << endl;
+		unloadPlugin(it->first);
 	}
-	msg("PluginManager finished unloading plugins");
+	vmsg("PluginManager finished unloading plugins");
         // Remove all plugin entries in the map.
 	plugin_map.clear();
 	msg("PluginManager unloading completed");
@@ -350,6 +354,7 @@ bool PluginManager::initializePlugin(const string& plugin_ident, LKbd & imyKbd,
 				init.config = &imyConfig;
 				init.plugins = iplugins;
 				init.verbose = verbose;
+				init.very_verbose = very_verbose;
 				init.global_enable = global_enable;
 				/* #ifdef HAVE_XOSD
 				init.have_display = true;
@@ -689,7 +694,7 @@ displayCtrl* PluginManager::getDisplay(const LConfig &config) {
        }
     }
     else
-       cout << "Display plugin not found" << endl;
+       msg("Display plugin not found");
 
     return (NULL);
 }
@@ -707,7 +712,7 @@ void PluginManager::print() {
 	}
 }
 void PluginManager::listPlugins() {
-	cout << "Listing Plugins" << endl;
+	msg("Listing Plugins");
 	map<string,plugin_info>::iterator it = plugin_map.begin();
 	for (; it != plugin_map.end(); it++) {
 	   cout << "Plugin " << it->first << " of type " << ((it->second).identifier)->type << endl;
