@@ -30,6 +30,8 @@
 
 #if __GNUC__ >= 3
    #include <ostream>
+   #include <iostream>
+   #include <sstream>
 #else
    	#include <ostream.h>
 #endif
@@ -226,7 +228,8 @@ int main(int argc, char *argv[])
    **************************************************************************************************/
 
   if (!X) {
-     X = new(Xmgr);
+     string dis = getenv("DISPLAY");
+     X = new Xmgr(dis);
      if ((!X->initialized()) || (X->getDisplay() == NULL)) {
         cerr << "Could not open display: " << getenv("DISPLAY") << endl;
   	cleanexit(false);
@@ -277,6 +280,7 @@ int main(int argc, char *argv[])
 
   /** Send appropriate control codes to the keyboard. */
   initialize_raw_keyboards(myConfig,myDef);
+  initialize_setkeycodes(myConfig,myDef);
 
   /* 
    if (very_verbose) {
@@ -406,6 +410,7 @@ int main(int argc, char *argv[])
 	         
 	         xev.xkey.state &= ~(numlock_mask | capslock_mask | scrolllock_mask);
 	         LKey *obj = static_cast<LKey*>(myKbd.getObject((int)xev.xkey.keycode));
+
 		 if (very_verbose) {
 		    cout << "Key press !" << endl;
 		    cout << "xev.xkey.keycode=" << xev.xkey.keycode << endl;
